CheckCommand class
Command to check architecture rules.
- Implemented types
Constructors
Properties
- description → String
-
Brief description of what the command does.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name (e.g., 'init').
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
List< String> arguments) → void -
Executes the command with the given arguments.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited