Module class

Represents a module in a Flutist project.

Constructors

Module({required String name, List<Dependency> dependencies = const [], List<Dependency> devDependencies = const [], List<Module> modules = const []})

Properties

dependencies List<Dependency>
Regular dependencies for 'dependencies' section.
final
devDependencies List<Dependency>
Development dependencies for 'dev_dependencies' section.
final
hashCode int
The hash code for this object.
no setterinherited
modules List<Module>
Sub-modules or module dependencies.
final
name String
Module name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited