ScaffoldType enum

Defines the scaffold template type used when creating a module. Used exclusively by flutist create --options and internal logic. Not stored in project.dart or package.dart.

Inheritance
Available extensions

Values

clean → const ScaffoldType

Clean Architecture: Domain / Data / Presentation (3 layers).

micro → const ScaffoldType

Microfeature Architecture: Example / Interface / Implementation / Tests / Testing (5 layers).

lite → const ScaffoldType

Microfeature lite: Interface / Implementation / Tests / Testing (4 layers).

simple → const ScaffoldType

Single package with no layers.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ScaffoldType
Parses a string to ScaffoldType.

Constants

values → const List<ScaffoldType>
A constant List of the values in this enum, in order of their declaration.