ProjectOptions class
Configuration options for a Flutist project.
Constructors
-
ProjectOptions({bool strictMode = true, List<
String> compositionRoots = const ['app']}) -
const
Properties
-
compositionRoots
→ List<
String> -
Modules allowed to directly reference Implementation layers.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strictMode → bool
-
Whether to enforce architecture rules during
flutist generate.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited